onoff.py - Add on(), off(), and trigger() event handling to any Python class
============================================================================

.. moduleauthor:: Dan McDougall <daniel.mcdougall@liftoffsoftware.com>

.. automodule:: onoff
    :members:
